pub struct PackBuilder { /* private fields */ }Implementations
Sourceimpl PackBuilder
impl PackBuilder
pub fn new() -> Self
pub fn from_options(options: PackOptions) -> Self
pub fn options(self, options: PackOptions) -> Self
pub fn preset(self, p: Preset) -> Self
pub fn budget(self, b: Budget) -> Self
pub fn max_tokens(self, n: usize) -> Self
pub fn reserve_tokens(self, n: usize) -> Self
pub fn tokenizer(self, t: Tokenizer) -> Self
pub fn scrub(self, on: bool) -> Self
pub fn expand_mode(self, m: ExpandMode) -> Self
pub fn include_path(self, path: impl Into<String>) -> Self
pub fn exclude_path(self, path: impl Into<String>) -> Self
Sourcepub fn diff_range(self, range: impl Into<String>) -> Self
pub fn diff_range(self, range: impl Into<String>) -> Self
Use an explicit Git diff range when collecting the Intent section.
By default packs use the working tree and index diff against HEAD.
Passing a range such as HEAD~3..HEAD makes the diff collector use
that range instead; related-test discovery is seeded from the same
filtered diff.
pub fn project_root(self, p: impl Into<PathBuf>) -> Self
pub fn stdin_prompt(self, prompt: impl Into<String>) -> Self
pub fn files_from(self, paths: Vec<PathBuf>) -> Self
pub fn impact_findings(self, findings: Vec<Finding>) -> Self
pub fn impact_per_finding(self, on: bool) -> Self
pub fn build(self) -> Result<Pack>