pub struct ReportConfig {
pub stderr_summary: bool,
pub fail_on_match: bool,
pub log_file: Option<PathBuf>,
pub max_entries: Option<usize>,
}Fields
stderr_summary: boolfail_on_match: boollog_file: Option<PathBuf>max_entries: Option<usize>Cap the scrub audit log to the most recent N entries. When set, the
log file is truncated after each write to retain only the newest
max_entries lines. None (default) means unbounded growth.